# Mediadex

Index media metadata into opensearch

## Usage

Give mediadex a path with music or movies:
```
mediadex --path /srv/music
```

... and watch as an opensearch index is quickly built!

You can now query opensearch about your media metadata with your
favourite tool such as opensearch-dashboard or curl.
